FilePublisherBase class abstract
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addErrorListener(
dynamic errorListener(Object error)?) → void -
addLogListener(
dynamic logListener(String log)?) → void -
addStateListener(
dynamic listener(PublishingState)?) → void -
connect(
{required String url, required PublisherProtocol mode}) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
publish(
{required String filePath, required String name, String? startTime}) → void -
stop(
) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited