LiveFilePublisher class

Inheritance
Implemented types

Constructors

LiveFilePublisher()

Properties

baseUrl String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
mode PublisherProtocol
getter/setter pair
publishingState PublishingState
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addErrorListener(dynamic errorListener(Object error)?) → void
add error listener
override
addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
addLogListener(dynamic logListener(String log)?) → void
add log lister
override
addStateListener(dynamic listener(PublishingState state)?) → void
add publishing state listener
override
connect({required String url, required PublisherProtocol mode}) → void
set the url and mode
override
dispose() → void
Discards any resources used by the object. After this is called, the object is not in a usable state and should be discarded (calls to addListener will throw after the object is disposed).
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
publish({required String filePath, required String name, String? startTime}) → void
override
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
stop() → void
stops the file ingestion
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited